=======
Credits
=======

Development Lead
----------------

* Simon Birrer <sibirrer@gmail.com>

Contributors
------------

* Ji Won Park `jiwoncpark <https://github.com/jiwoncpark/>`_
* Aymeric Galan `aymgal <https://github.com/aymgal/>`_
